==> haskell-doctest-lib-0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-lib
version:              0.1
visibility:           public
id:                   doctest-lib-0.1-KkYFPgyxYmQ4oujE28nmhc
key:                  doctest-lib-0.1-KkYFPgyxYmQ4oujE28nmhc
license:              MIT
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:
    Henning Thielemann <haskell@henning-thielemann.de>, Simon Hengel <sol@typeful.net>

homepage:             https://hub.darcs.net/thielema/doctest-lib/
synopsis:             Parts of doctest exposed as library
description:
    Parts of doctest exposed as library.
    For use with the doctest-extract utility.

category:             Testing
abi:                  ecfaa9c92b46a8ea7631fd8276b1b5df
exposed:              True
exposed-modules:
    Test.DocTest.Base Test.DocTest.Location Test.DocTest.Parse

import-dirs:          /usr/lib/ghc-9.0.1/site-local/doctest-lib-0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/doctest-lib-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/doctest-lib-0.1
hs-libraries:         HSdoctest-lib-0.1-KkYFPgyxYmQ4oujE28nmhc
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-doctest-lib/html/doctest-lib.haddock
haddock-html:         /usr/share/doc/haskell-doctest-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-lib-0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-lib
version:              0.1
visibility:           public
id:                   doctest-lib-0.1-Cb2ex7j622yHiKfkw3BhRJ
key:                  doctest-lib-0.1-Cb2ex7j622yHiKfkw3BhRJ
license:              MIT
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:
    Henning Thielemann <haskell@henning-thielemann.de>, Simon Hengel <sol@typeful.net>

homepage:             https://hub.darcs.net/thielema/doctest-lib/
synopsis:             Parts of doctest exposed as library
description:
    Parts of doctest exposed as library.
    For use with the doctest-extract utility.

category:             Testing
abi:                  e2a3a35abbaa839e5d8105af55dd433c
exposed:              True
exposed-modules:
    Test.DocTest.Base Test.DocTest.Location Test.DocTest.Parse

import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-lib-0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-lib-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/doctest-lib-0.1
hs-libraries:         HSdoctest-lib-0.1-Cb2ex7j622yHiKfkw3BhRJ
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-doctest-lib/html/doctest-lib.haddock
haddock-html:         /usr/share/doc/haskell-doctest-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
